@@ -7,7 +7,7 @@ use DBD::Cassandra::dr;
 use DBD::Cassandra::db;
 use DBD::Cassandra::st;
 
-our $VERSION= '0.51';
+our $VERSION= '0.52';
 our $drh= undef;
 
 sub driver {
@@ -205,7 +205,7 @@ handles in large volumes of inserts :
     my (@pending, @reusable);
 
     while (my $row= shift @dataset_to_insert) {
-        my $sth= (shift @reusable) // $dbh->prepare(
+        my $sth= (shift @reusable) || $dbh->prepare(
             "INSERT INTO some_table (a, b, c, d) VALUES (?, ?, ?, ?)"
         );
         $sth->execute(@$row);
@@ -252,8 +252,11 @@ Thread support is untested. Use at your own risk.
 
 =item *
 
-If the table structure changes, prepared queries are not invalidated correctly.
-This is a serious issue and will be fixed in a future release.
+The C<timestamp> format is implemented naively by returning
+milliseconds since the UNIX epoch. In Perl you get this number through
+C<time() * 1000>. Trying to save times as C<DateTime> objects or
+strings will not work, and will likely result in warnings and
+unexpected behavior.
 
 =item *
 
